==> kadu_0.10.1.orig.tar.bz2: kadu-0.10.1/plugins/encryption_ng/translations/encryption_ng_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pl">
<context>
    <name>@default</name>
    <message>
        <source>Chat</source>
        <translation>Rozmowa</translation>
    </message>
    <message>
        <source>Encryption</source>
        <translation>Szyfrowanie</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Ogólne</translation>
    </message>
    <message>
        <source>Encrypt by default</source>
        <translation>Domyślnie szyfruj</translation>
    </message>
    <message>
        <source>Encrypt after receive encrypted message</source>
        <translation>Szyfruj po otrzymaniu zaszyfrowanej wiadomości</translation>
    </message>
    <message>
        <source>Public key has been sent</source>
        <translation>Klucz publiczny został wysłany</translation>
    </message>
    <message>
        <source>Error during sending public key</source>
        <translation>Błąd podczas wysyłania klucza publicznego</translation>
    </message>
    <message>
        <source>Encryption error has occured</source>
        <translation>Błąd szyfrowania</translation>
    </message>
</context>
<context>
    <name>EncryptionActions</name>
    <message>
        <source>Encrypt</source>
        <translation>Szyfruj</translation>
    </message>
    <message>
        <source>Send My Public Key</source>
        <translation>Wyślij mój klucz publiczny</translation>
    </message>
    <message>
        <source>Encryption</source>
        <translation>Szyfrowanie</translation>
    </message>
    <message>
        <source>Cannot generate keys. Check if encryption_simlite module is loaded</source>
        <translation>Nie można wygenerować kluczy. Sprawdź czy moduł encryption_simlite jest załadowany</translation>
    </message>
    <message>
        <source>Keys exist. Do you want to overwrite them?</source>
        <translation>Klucze istnieją. Czy chcesz je nadpisać?</translation>
    </message>
    <message>
        <source>Keys have been generated</source>
        <translation>Klucze zostały wygenerowane</translation>
    </message>
    <message>
        <source>Error generating keys</source>
        <translation>Błąd generowania kluczy</translation>
    </message>
    <message>
        <source>No public key available</source>
        <translation>Brak klucza publicznego</translation>
    </message>
    <message>
        <source>Generate Encryption Keys</source>
        <translation>Wygeneruj klucze szyfrowania</translation>
    </message>
</context>
<context>
    <name>EncryptionNgNotification</name>
    <message>
        <source>Encryption</source>
        <translation>Szyfrowanie</translation>
    </message>
    <message>
        <source>Public key has been send to: %1 (%2)</source>
        <translation>Klucz publiczny został wysłany do: %1 (%2)</translation>
    </message>
    <message>
        <source>Error sending public key to: %1 (%2)</source>
        <translation>Wystąpił błąd podczas wysyłania klucza do:  %1 (%2)</translation>
    </message>
    <message>
        <source>Error occured during encryption</source>
        <translation>Wystąpił błąd podczas szyfrowania</translation>
    </message>
</context>
<context>
    <name>EncryptionNgPlugin</name>
    <message>
        <source>Encryption</source>
        <translation>Szyfrowanie</translation>
    </message>
    <message>
        <source>The QCA OSSL plugin for libqca2 is not present!</source>
        <translation>Wtyczka QCA OSSL dla libqca2 jest niedostępna!</translation>
    </message>
</context>
<context>
    <name>EncryptionProviderManager</name>
    <message>
        <source>Buddy %1 is sending you his public key.
Do you want to save it?</source>
        <translation>Znajomy %1 przysłał Ci swój klucz publiczny.
Chcesz go zapisać?</translation>
    </message>
    <message>
        <source>Encryption</source>
        <translation>Szyfrowanie</translation>
    </message>
</context>
</TS>

==> kadu_0.11.0~rc2.orig.tar.bz2: kadu-0.11.0-rc2/plugins/encryption_ng/translations/encryption_ng_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pl">
<context>
    <name>@default</name>
    <message>
        <source>Chat</source>
        <translation>Rozmowa</translation>
    </message>
    <message>
        <source>Encryption</source>
        <translation>Szyfrowanie</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Ogólne</translation>
    </message>
    <message>
        <source>Encrypt by default</source>
        <translation>Domyślnie szyfruj</translation>
    </message>
    <message>
        <source>Encrypt after receive encrypted message</source>
        <translation>Szyfruj po otrzymaniu zaszyfrowanej wiadomości</translation>
    </message>
    <message>
        <source>Public key has been sent</source>
        <translation>Klucz publiczny został wysłany</translation>
    </message>
    <message>
        <source>Error during sending public key</source>
        <translation>Błąd podczas wysyłania klucza publicznego</translation>
    </message>
    <message>
        <source>Encryption error has occured</source>
        <translation>Błąd szyfrowania</translation>
    </message>
</context>
<context>
    <name>EnableEncryptionActionDescription</name>
    <message>
        <source>Encrypt</source>
        <translation>Szyfruj</translation>
    </message>
</context>
<context>
    <name>EncryptionNgNotification</name>
    <message>
        <source>Encryption</source>
        <translation>Szyfrowanie</translation>
    </message>
    <message>
        <source>Public key has been send to: %1 (%2)</source>
        <translation>Klucz publiczny został wysłany do: %1 (%2)</translation>
    </message>
    <message>
        <source>Error sending public key to: %1 (%2)</source>
        <translation>Wystąpił błąd podczas wysyłania klucza do:  %1 (%2)</translation>
    </message>
    <message>
        <source>Error occured during encryption</source>
        <translation>Wystąpił błąd podczas szyfrowania</translation>
    </message>
</context>
<context>
    <name>EncryptionNgPlugin</name>
    <message>
        <source>Encryption</source>
        <translation>Szyfrowanie</translation>
    </message>
    <message>
        <source>The QCA OSSL plugin for libqca2 is not present!</source>
        <translation>Wtyczka QCA OSSL dla libqca2 jest niedostępna!</translation>
    </message>
</context>
<context>
    <name>EncryptionProviderManager</name>
    <message>
        <source>Buddy %1 is sending you his public key.
Do you want to save it?</source>
        <translation>Znajomy %1 przysłał Ci swój klucz publiczny.
Chcesz go zapisać?</translation>
    </message>
    <message>
        <source>Encryption</source>
        <translation>Szyfrowanie</translation>
    </message>
</context>
<context>
    <name>GenerateKeysActionDescription</name>
    <message>
        <source>Encryption</source>
        <translation>Szyfrowanie</translation>
    </message>
    <message>
        <source>Cannot generate keys. Check if encryption_simlite module is loaded</source>
        <translation>Nie można wygenerować kluczy. Sprawdź czy moduł encryption_simlite jest załadowany</translation>
    </message>
    <message>
        <source>Keys exist. Do you want to overwrite them?</source>
        <translation>Klucze istnieją. Czy chcesz je nadpisać?</translation>
    </message>
    <message>
        <source>Keys have been generated</source>
        <translation>Klucze zostały wygenerowane</translation>
    </message>
    <message>
        <source>Error generating keys</source>
        <translation>Błąd generowania kluczy</translation>
    </message>
    <message>
        <source>Generate Encryption Keys</source>
        <translation>Wygeneruj klucze szyfrowania</translation>
    </message>
</context>
<context>
    <name>SendPublicKeyActionDescription</name>
    <message>
        <source>Send My Public Key</source>
        <translation>Wyślij mój klucz publiczny</translation>
    </message>
    <message>
        <source>No public key available</source>
        <translation>Brak klucza publicznego</translation>
    </message>
</context>
</TS>
